==> openshift-model-5.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/SourceControlUserFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SourceControlUserFluentImpl<A extends SourceControlUserFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SourceControlUserFluent<A> {

    private String email;
    private String name;

    public SourceControlUserFluentImpl() {
    }

    public SourceControlUserFluentImpl(SourceControlUser instance) {
        this.withEmail(instance.getEmail()); 
        this.withName(instance.getName()); 
    }

    public String getEmail() {
        return this.email;
    }

    public A withEmail(String email) {
        this.email=email; return (A) this;
    }

    public Boolean hasEmail() {
        return this.email != null;
    }

    public A withNewEmail(String arg1) {
        return (A)withEmail(new String(arg1));
    }

    public A withNewEmail(StringBuilder arg1) {
        return (A)withEmail(new String(arg1));
    }

    public A withNewEmail(StringBuffer arg1) {
        return (A)withEmail(new String(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SourceControlUserFluentImpl that = (SourceControlUserFluentImpl) o;
        if (email != null ? !email.equals(that.email) :that.email != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(email,  name,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/SourceControlUserFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SourceControlUserFluentImpl<A extends SourceControlUserFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SourceControlUserFluent<A> {

    private String email;
    private String name;

    public SourceControlUserFluentImpl() {
    }

    public SourceControlUserFluentImpl(SourceControlUser instance) {
        this.withEmail(instance.getEmail()); 
        this.withName(instance.getName()); 
    }

    public String getEmail() {
        return this.email;
    }

    public A withEmail(String email) {
        this.email=email; return (A) this;
    }

    public Boolean hasEmail() {
        return this.email != null;
    }

    public A withNewEmail(StringBuilder arg1) {
        return (A)withEmail(new String(arg1));
    }

    public A withNewEmail(int[] arg1,int arg2,int arg3) {
        return (A)withEmail(new String(arg1, arg2, arg3));
    }

    public A withNewEmail(char[] arg1) {
        return (A)withEmail(new String(arg1));
    }

    public A withNewEmail(StringBuffer arg1) {
        return (A)withEmail(new String(arg1));
    }

    public A withNewEmail(byte[] arg1,int arg2) {
        return (A)withEmail(new String(arg1, arg2));
    }

    public A withNewEmail(byte[] arg1) {
        return (A)withEmail(new String(arg1));
    }

    public A withNewEmail(char[] arg1,int arg2,int arg3) {
        return (A)withEmail(new String(arg1, arg2, arg3));
    }

    public A withNewEmail(byte[] arg1,int arg2,int arg3) {
        return (A)withEmail(new String(arg1, arg2, arg3));
    }

    public A withNewEmail(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withEmail(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewEmail(String arg1) {
        return (A)withEmail(new String(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(int[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(char[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(byte[] arg1,int arg2) {
        return (A)withName(new String(arg1, arg2));
    }

    public A withNewName(byte[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(char[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SourceControlUserFluentImpl that = (SourceControlUserFluentImpl) o;
        if (email != null ? !email.equals(that.email) :that.email != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(email,  name,  super.hashCode());
    }

}
